@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.41 2004/06/09 18:19:48 richb Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/functions.c,v 1.41.2.1 2004/11/04 20:43:05 richb Exp $
  *
  *  Copyright (c) 1987-2003 Sun Microsystems, Inc. All Rights Reserved.
  *           
@@ -709,7 +709,7 @@ do_paren()
             return;
         }
     }
-    paren_disp(v->current->func_char);
+    paren_disp(v->current->value[0]);
 }
 
 
